@@ -99,8 +99,8 @@ dipole['C_3'] = np.array([[[xxx, -yyy, yyz], [-yyy, -xxx, -yxz], [yzy, -yzx, 0]]
 dipole['C_3v'] = np.array([[[0, xyx, yyz], [xyx, 0, 0], [yzy, 0, 0]], [[xyx, 0, 0], [0, -xyx, yyz], [0, yzy, 0]], [[zyy, 0, 0], [0, zyy, 0], [0, 0, zzz]]], dtype=object)
 dipole['C_6'] = np.array([[[0, 0, yyz], [0, 0, -yxz], [yzy, -yzx, 0]], [[0, 0, yxz], [0, 0, yyz], [yzx, yzy, 0]], [[zyy, -zyx, 0], [zyx, zyy, 0], [0, 0, zzz]]], dtype=object)
 dipole['C_3h'] = np.array([[[-yyx, xxy, 0], [xxy, yyx, 0], [0, 0, 0]], [[xxy, yyx, 0], [yyx, -xxy, 0], [0, 0, 0]], [[0, 0, 0], [0, 0, 0], [0, 0, 0]]], dtype=object)
-dipole['D_6'] = np.array([[[0, 0, 0], [0, 0, -yxz], [0, -yxz, 0]], [[0, 0, yxz], [0, 0, 0], [0, 0, 0]], [[0, -zyx, 0], [zyx, 0, 0], [0, 0, 0]]], dtype=object)
 dipole['C_6v'] = np.array([[[0, 0, yyz], [0, 0, 0], [yzy, 0, 0]], [[0, 0, 0], [0, 0, yyz], [0, yzy, 0]], [[zyy, 0, 0], [0, zyy, 0], [0, 0, zzz]]], dtype=object)
+dipole['D_6'] = np.array([[[0, 0, 0], [0, 0, -yxz], [0, -yzx, 0]], [[0, 0, yxz], [0, 0, 0], [yzx, 0, 0]], [[0, -zyx, 0], [zyx, 0, 0], [0, 0, 0]]], dtype=object)
 dipole['D_3h'] = np.array([[[0, xyx, 0], [xyx, 0, 0], [0, 0, 0]], [[xyx, 0, 0], [0, -xyx, 0], [0, 0, 0]], [[0, 0, 0], [0, 0, 0], [0, 0, 0]]], dtype=object)
 dipole['C_1'] = np.array([[[xxx, xxy, xxz], [xyx, xyy, xyz], [xzx, xzy, xzz]], [[yxx, yxy, yxz], [yyx, yyy, yyz], [yzx, yzy, yzz]], [[zxx, zxy, zxz], [zyx, zyy, zyz], [zzx, zzy, zzz]]], dtype=object)
 for k,v in dipole.items():
@@ -138,7 +138,7 @@ surface['C_3'] = np.array([[[sxxx, -syyy, syyz], [-syyy, -sxxx, -syxz], [syzy, -
 surface['C_3v'] = np.array([[[0, sxyx, syyz], [sxyx, 0, 0], [syzy, 0, 0]], [[sxyx, 0, 0], [0, -sxyx, syyz], [0, syzy, 0]], [[szyy, 0, 0], [0, szyy, 0], [0, 0, szzz]]], dtype=object)
 surface['C_6'] = np.array([[[0, 0, syyz], [0, 0, -syxz], [syzy, -syzx, 0]], [[0, 0, syxz], [0, 0, syyz], [syzx, syzy, 0]], [[szyy, -szyx, 0], [szyx, szyy, 0], [0, 0, szzz]]], dtype=object)
 surface['C_3h'] = np.array([[[-syyx, sxxy, 0], [sxxy, syyx, 0], [0, 0, 0]], [[sxxy, syyx, 0], [syyx, -sxxy, 0], [0, 0, 0]], [[0, 0, 0], [0, 0, 0], [0, 0, 0]]], dtype=object)
-surface['D_6'] = np.array([[[0, 0, 0], [0, 0, -syxz], [0, -syxz, 0]], [[0, 0, syxz], [0, 0, 0], [0, 0, 0]], [[0, -szyx, 0], [szyx, 0, 0], [0, 0, 0]]], dtype=object)
+surface['D_6'] = np.array([[[0, 0, 0], [0, 0, -syxz], [0, -syzx, 0]], [[0, 0, syxz], [0, 0, 0], [syzx, 0, 0]], [[0, -szyx, 0], [szyx, 0, 0], [0, 0, 0]]], dtype=object)
 surface['C_6v'] = np.array([[[0, 0, syyz], [0, 0, 0], [syzy, 0, 0]], [[0, 0, 0], [0, 0, syyz], [0, syzy, 0]], [[szyy, 0, 0], [0, szyy, 0], [0, 0, szzz]]], dtype=object)
 surface['D_3h'] = np.array([[[0, sxyx, 0], [sxyx, 0, 0], [0, 0, 0]], [[sxyx, 0, 0], [0, -sxyx, 0], [0, 0, 0]], [[0, 0, 0], [0, 0, 0], [0, 0, 0]]], dtype=object)
 surface['C_1'] = np.array([[[sxxx, sxxy, sxxz], [sxyx, sxyy, sxyz], [sxzx, sxzy, sxzz]], [[syxx, syxy, syxz], [syyx, syyy, syyz], [syzx, syzy, syzz]], [[szxx, szxy, szxz], [szyx, szyy, szyz], [szzx, szzy, szzz]]], dtype=object)
@@ -167,9 +167,9 @@ quadrupole['S_6'] = np.array([[[[yxxy + yxyx + yyxx, -xxyx - xyxx - yxxx, -yyxz]
 quadrupole['C_3v'] = np.array([[[[yxxy + yxyx + yyxx, 0, -yyxz], [0, yyxx, 0], [-yyzx, 0, xxzz]], [[0, yxyx, 0], [yxxy, 0, yyxz], [0, yyzx, 0]], [[-yzyx, 0, xzxz], [0, yzyx, 0], [xzzx, 0, 0]]], [[[0, yxxy, 0], [yxyx, 0, yyxz], [0, yyzx, 0]], [[yyxx, 0, yyxz], [0, yxxy + yxyx + yyxx, 0], [yyzx, 0, xxzz]], [[0, yzyx, 0], [yzyx, 0, xzxz], [0, xzzx, 0]]], [[[-zyyx, 0, zxxz], [0, zyyx, 0], [zxzx, 0, 0]], [[0, zyyx, 0], [zyyx, 0, zxxz], [0, zxzx, 0]], [[zzxx, 0, 0], [0, zzxx, 0], [0, 0, zzzz]]]], dtype=object)
 quadrupole['D_3d'] = np.array([[[[yxxy + yxyx + yyxx, 0, -yyxz], [0, yyxx, 0], [-yyzx, 0, xxzz]], [[0, yxyx, 0], [yxxy, 0, yyxz], [0, yyzx, 0]], [[-yzyx, 0, xzxz], [0, yzyx, 0], [xzzx, 0, 0]]], [[[0, yxxy, 0], [yxyx, 0, yyxz], [0, yyzx, 0]], [[yyxx, 0, yyxz], [0, yxxy + yxyx + yyxx, 0], [yyzx, 0, xxzz]], [[0, yzyx, 0], [yzyx, 0, xzxz], [0, xzzx, 0]]], [[[-zyyx, 0, zxxz], [0, zyyx, 0], [zxzx, 0, 0]], [[0, zyyx, 0], [zyyx, 0, zxxz], [0, zxzx, 0]], [[zzxx, 0, 0], [0, zzxx, 0], [0, 0, zzzz]]]], dtype=object)
 quadrupole['D_3'] = np.array([[[[yxxy + yxyx + yyxx, 0, -yyxz], [0, yyxx, 0], [-yyzx, 0, xxzz]], [[0, yxyx, 0], [yxxy, 0, yyxz], [0, yyzx, 0]], [[-yzyx, 0, xzxz], [0, yzyx, 0], [xzzx, 0, 0]]], [[[0, yxxy, 0], [yxyx, 0, yyxz], [0, yyzx, 0]], [[yyxx, 0, yyxz], [0, yxxy + yxyx + yyxx, 0], [yyzx, 0, xxzz]], [[0, yzyx, 0], [yzyx, 0, xzxz], [0, xzzx, 0]]], [[[-zyyx, 0, zxxz], [0, zyyx, 0], [zxzx, 0, 0]], [[0, zyyx, 0], [zyyx, 0, zxxz], [0, zxzx, 0]], [[zzxx, 0, 0], [0, zzxx, 0], [0, 0, zzzz]]]], dtype=object)
-quadrupole['C_4h'] = np.array([[[[yyyy, -yyyx, 0], [-yyxy, yyxx, 0], [0, 0, zzyy]], [[-yxyy, yxyx, 0], [yxxy, xyyy, 0], [0, 0, -yxzz]], [[0, 0, yzyz], [0, 0, -yzxz], [yzzy, -yzzx, 0]]], [[[-xyyy, yxxy, 0], [yxyx, yxyy, 0], [0, 0, yxzz]], [[yyxx, yyxy, 0], [yyyx, yyyy, 0], [0, 0, 0]], [[0, 0, yzxz], [0, 0, yzyz], [yzzx, yzzy, 0]]], [[[0, 0, zyyz], [0, 0, -zyxz], [zyzy, -zyzx, 0]], [[0, 0, zyxz], [0, 0, zyyz], [zyzx, zyzy, 0]], [[zzyy, -zzyx, 0], [zzyx, zzyy, 0], [0, 0, zzzz]]]], dtype=object)
-quadrupole['C_4'] = np.array([[[[yyyy, -yyyx, 0], [-yyxy, yyxx, 0], [0, 0, zzyy]], [[-yxyy, yxyx, 0], [yxxy, xyyy, 0], [0, 0, -yxzz]], [[0, 0, yzyz], [0, 0, -yzxz], [yzzy, -yzzx, 0]]], [[[-xyyy, yxxy, 0], [yxyx, yxyy, 0], [0, 0, yxzz]], [[yyxx, yyxy, 0], [yyyx, yyyy, 0], [0, 0, 0]], [[0, 0, yzxz], [0, 0, yzyz], [yzzx, yzzy, 0]]], [[[0, 0, zyyz], [0, 0, -zyxz], [zyzy, -zyzx, 0]], [[0, 0, zyxz], [0, 0, zyyz], [zyzx, zyzy, 0]], [[zzyy, -zzyx, 0], [zzyx, zzyy, 0], [0, 0, zzzz]]]], dtype=object)
-quadrupole['S_4'] = np.array([[[[yyyy, -yyyx, 0], [-yyxy, yyxx, 0], [0, 0, zzyy]], [[-yxyy, yxyx, 0], [yxxy, xyyy, 0], [0, 0, -yxzz]], [[0, 0, yzyz], [0, 0, -yzxz], [yzzy, -yzzx, 0]]], [[[-xyyy, yxxy, 0], [yxyx, yxyy, 0], [0, 0, yxzz]], [[yyxx, yyxy, 0], [yyyx, yyyy, 0], [0, 0, 0]], [[0, 0, yzxz], [0, 0, yzyz], [yzzx, yzzy, 0]]], [[[0, 0, zyyz], [0, 0, -zyxz], [zyzy, -zyzx, 0]], [[0, 0, zyxz], [0, 0, zyyz], [zyzx, zyzy, 0]], [[zzyy, -zzyx, 0], [zzyx, zzyy, 0], [0, 0, zzzz]]]], dtype=object)
+quadrupole['C_4'] = np.array([[[[yyyy, -yyyx, 0], [-yyxy, yyxx, 0], [0, 0, yyzz]], [[-yxyy, yxyx, 0], [yxxy, xyyy, 0], [0, 0, -yxzz]], [[0, 0, yzyz], [0, 0, -yzxz], [yzzy, -yzzx, 0]]], [[[-xyyy, yxxy, 0], [yxyx, yxyy, 0], [0, 0, yxzz]], [[yyxx, yyxy, 0], [yyyx, yyyy, 0], [0, 0, yyzz]], [[0, 0, yzxz], [0, 0, yzyz], [yzzx, yzzy, 0]]], [[[0, 0, zyyz], [0, 0, -zyxz], [zyzy, -zyzx, 0]], [[0, 0, zyxz], [0, 0, zyyz], [zyzx, zyzy, 0]], [[zzyy, -zzyx, 0], [zzyx, zzyy, 0], [0, 0, zzzz]]]], dtype=object)
+quadrupole['C_4h'] = np.array([[[[yyyy, -yyyx, 0], [-yyxy, yyxx, 0], [0, 0, yyzz]], [[-yxyy, yxyx, 0], [yxxy, xyyy, 0], [0, 0, -yxzz]], [[0, 0, yzyz], [0, 0, -yzxz], [yzzy, -yzzx, 0]]], [[[-xyyy, yxxy, 0], [yxyx, yxyy, 0], [0, 0, yxzz]], [[yyxx, yyxy, 0], [yyyx, yyyy, 0], [0, 0, yyzz]], [[0, 0, yzxz], [0, 0, yzyz], [yzzx, yzzy, 0]]], [[[0, 0, zyyz], [0, 0, -zyxz], [zyzy, -zyzx, 0]], [[0, 0, zyxz], [0, 0, zyyz], [zyzx, zyzy, 0]], [[zzyy, -zzyx, 0], [zzyx, zzyy, 0], [0, 0, zzzz]]]], dtype=object)
+quadrupole['S_4'] = np.array([[[[yyyy, -yyyx, 0], [-yyxy, yyxx, 0], [0, 0, yyzz]], [[-yxyy, yxyx, 0], [yxxy, xyyy, 0], [0, 0, -yxzz]], [[0, 0, yzyz], [0, 0, -yzxz], [yzzy, -yzzx, 0]]], [[[-xyyy, yxxy, 0], [yxyx, yxyy, 0], [0, 0, yxzz]], [[yyxx, yyxy, 0], [yyyx, yyyy, 0], [0, 0, yyzz]], [[0, 0, yzxz], [0, 0, yzyz], [yzzx, yzzy, 0]]], [[[0, 0, zyyz], [0, 0, -zyxz], [zyzy, -zyzx, 0]], [[0, 0, zyxz], [0, 0, zyyz], [zyzx, zyzy, 0]], [[zzyy, -zzyx, 0], [zzyx, zzyy, 0], [0, 0, zzzz]]]], dtype=object)
 quadrupole['C_4v'] = np.array([[[[yyyy, 0, 0], [0, yyxx, 0], [0, 0, xxzz]], [[0, yxyx, 0], [yxxy, 0, 0], [0, 0, 0]], [[0, 0, xzxz], [0, 0, 0], [xzzx, 0, 0]]], [[[0, yxxy, 0], [yxyx, 0, 0], [0, 0, 0]], [[yyxx, 0, 0], [0, yyyy, 0], [0, 0, xxzz]], [[0, 0, 0], [0, 0, xzxz], [0, xzzx, 0]]], [[[0, 0, zxxz], [0, 0, 0], [zxzx, 0, 0]], [[0, 0, 0], [0, 0, zxxz], [0, zxzx, 0]], [[zzxx, 0, 0], [0, zzxx, 0], [0, 0, zzzz]]]], dtype=object)
 quadrupole['D_4'] = np.array([[[[yyyy, 0, 0], [0, yyxx, 0], [0, 0, xxzz]], [[0, yxyx, 0], [yxxy, 0, 0], [0, 0, 0]], [[0, 0, xzxz], [0, 0, 0], [xzzx, 0, 0]]], [[[0, yxxy, 0], [yxyx, 0, 0], [0, 0, 0]], [[yyxx, 0, 0], [0, yyyy, 0], [0, 0, xxzz]], [[0, 0, 0], [0, 0, xzxz], [0, xzzx, 0]]], [[[0, 0, zxxz], [0, 0, 0], [zxzx, 0, 0]], [[0, 0, 0], [0, 0, zxxz], [0, zxzx, 0]], [[zzxx, 0, 0], [0, zzxx, 0], [0, 0, zzzz]]]], dtype=object)
 quadrupole['D_4h'] = np.array([[[[yyyy, 0, 0], [0, yyxx, 0], [0, 0, xxzz]], [[0, yxyx, 0], [yxxy, 0, 0], [0, 0, 0]], [[0, 0, xzxz], [0, 0, 0], [xzzx, 0, 0]]], [[[0, yxxy, 0], [yxyx, 0, 0], [0, 0, 0]], [[yyxx, 0, 0], [0, yyyy, 0], [0, 0, xxzz]], [[0, 0, 0], [0, 0, xzxz], [0, xzzx, 0]]], [[[0, 0, zxxz], [0, 0, 0], [zxzx, 0, 0]], [[0, 0, 0], [0, 0, zxxz], [0, zxzx, 0]], [[zzxx, 0, 0], [0, zzxx, 0], [0, 0, zzzz]]]], dtype=object)
